==> jc-1.4.0.tar.gz: java/util/jar/JarFile__24EntryInputStream.h <==
// class java.util.jar.JarFile$EntryInputStream

// class file dependencies
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3402779c758f954c java_util_jar_JarFile__24EntryInputStream

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_java_util_jar_JarFile__24EntryInputStream_H_
#define _JC_java_util_jar_JarFile__24EntryInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_jar_JarFile$object;
struct _jc_java_util_zip_ZipEntry$object;

// Typedefs
typedef struct _jc_java_util_jar_JarFile__24EntryInputStream$sub_refs	_jc_java_util_jar_JarFile__24EntryInputStream$sub_refs;
typedef struct _jc_java_util_jar_JarFile__24EntryInputStream$sub_nonrefs	_jc_java_util_jar_JarFile__24EntryInputStream$sub_nonrefs;
typedef struct _jc_java_util_jar_JarFile__24EntryInputStream$refs	_jc_java_util_jar_JarFile__24EntryInputStream$refs;
typedef struct _jc_java_util_jar_JarFile__24EntryInputStream$nonrefs	_jc_java_util_jar_JarFile__24EntryInputStream$nonrefs;
typedef struct _jc_java_util_jar_JarFile__24EntryInputStream$object	_jc_java_util_jar_JarFile__24EntryInputStream$object;

typedef const struct _jc_java_util_jar_JarFile__24EntryInputStream$vmethods	_jc_java_util_jar_JarFile__24EntryInputStream$vmethods;
typedef const struct _jc_java_util_jar_JarFile__24EntryInputStream$vtable	_jc_java_util_jar_JarFile__24EntryInputStream$vtable;
typedef const struct _jc_java_util_jar_JarFile__24EntryInputStream$vtype	_jc_java_util_jar_JarFile__24EntryInputStream$vtype;

// Constructors
extern void _jc_java_util_jar_JarFile__24EntryInputStream$method$_init$a2cee451c38f95fe(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, struct _jc_java_util_zip_ZipEntry$object *, struct _jc_java_io_InputStream$object *, struct _jc_java_util_jar_JarFile$object *);

// Virtual methods
extern void _jc_java_util_jar_JarFile__24EntryInputStream$method$eof$36b390d2a773f09b(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *);
extern void _jc_java_util_jar_JarFile__24EntryInputStream$method$mark$422af117ab27d9db(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, jint);
extern jboolean _jc_java_util_jar_JarFile__24EntryInputStream$method$markSupported$66435a81b7b2f2dc(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *);
extern jint _jc_java_util_jar_JarFile__24EntryInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *);
extern jint _jc_java_util_jar_JarFile__24EntryInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, struct _jc_byte_array *);
extern jint _jc_java_util_jar_JarFile__24EntryInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_java_util_jar_JarFile__24EntryInputStream$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *);
extern jlong _jc_java_util_jar_JarFile__24EntryInputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, jlong);

// Virtual method descriptors
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$eof$36b390d2a773f09b;
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$mark$422af117ab27d9db;
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$markSupported$66435a81b7b2f2dc;
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$skip$4e431136b5c4614a;

// Virtual methods structure
struct _jc_java_util_jar_JarFile__24EntryInputStream$vmethods {
	void	(*eof$36b390d2a773f09b)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *);
	void	(*mark$422af117ab27d9db)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, jint);
	jboolean	(*markSupported$66435a81b7b2f2dc)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *);
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, struct _jc_byte_array *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *);
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, jlong);
};

// Vtable
struct _jc_java_util_jar_JarFile__24EntryInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_java_util_jar_JarFile__24EntryInputStream$vmethods	java_util_jar_JarFile__24EntryInputStream;
};

// Vtype
struct _jc_java_util_jar_JarFile__24EntryInputStream$vtype {
	_jc_type			type;
	_jc_java_util_jar_JarFile__24EntryInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_jar_JarFile__24EntryInputStream$sub_refs {
	struct _jc_java_util_jar_JarFile$object	*jarfile;
	struct _jc_java_util_zip_ZipEntry$object	*entry;
	_jc_object_array	*hashes;
	_jc_object_array	*md;
};

// Reference instance fields (object)
struct _jc_java_util_jar_JarFile__24EntryInputStream$refs {
    _jc_java_util_jar_JarFile__24EntryInputStream$sub_refs	java_util_jar_JarFile__24EntryInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_jar_JarFile__24EntryInputStream$sub_nonrefs {
	jlong	length;
	jlong	pos;
	jboolean	checked;
};

// Non-reference instance fields (object)
struct _jc_java_util_jar_JarFile__24EntryInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_java_util_jar_JarFile__24EntryInputStream$sub_nonrefs	java_util_jar_JarFile__24EntryInputStream;
};

// Object instance structure
struct _jc_java_util_jar_JarFile__24EntryInputStream$object {
	_jc_java_util_jar_JarFile__24EntryInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_jar_JarFile__24EntryInputStream$vtype	*vtype;
	_jc_java_util_jar_JarFile__24EntryInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_jar_JarFile__24EntryInputStream$vtype _jc_java_util_jar_JarFile__24EntryInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_jar_JarFile__24EntryInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_jar_JarFile__24EntryInputStream$class_object;

#endif	/* _JC_java_util_jar_JarFile__24EntryInputStream_H_ */

==> jc-1.4.5.tar.gz: java/util/jar/JarFile__24EntryInputStream.h <==
// class java.util.jar.JarFile$EntryInputStream

// class file dependencies
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3402779c758f954c java_util_jar_JarFile__24EntryInputStream

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_java_util_jar_JarFile__24EntryInputStream_H_
#define _JC_java_util_jar_JarFile__24EntryInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_jar_JarFile$object;
struct _jc_java_util_zip_ZipEntry$object;

// Typedefs
typedef struct _jc_java_util_jar_JarFile__24EntryInputStream$sub_refs	_jc_java_util_jar_JarFile__24EntryInputStream$sub_refs;
typedef struct _jc_java_util_jar_JarFile__24EntryInputStream$sub_nonrefs	_jc_java_util_jar_JarFile__24EntryInputStream$sub_nonrefs;
typedef struct _jc_java_util_jar_JarFile__24EntryInputStream$refs	_jc_java_util_jar_JarFile__24EntryInputStream$refs;
typedef struct _jc_java_util_jar_JarFile__24EntryInputStream$nonrefs	_jc_java_util_jar_JarFile__24EntryInputStream$nonrefs;
typedef struct _jc_java_util_jar_JarFile__24EntryInputStream$object	_jc_java_util_jar_JarFile__24EntryInputStream$object;

typedef const struct _jc_java_util_jar_JarFile__24EntryInputStream$vmethods	_jc_java_util_jar_JarFile__24EntryInputStream$vmethods;
typedef const struct _jc_java_util_jar_JarFile__24EntryInputStream$vtable	_jc_java_util_jar_JarFile__24EntryInputStream$vtable;
typedef const struct _jc_java_util_jar_JarFile__24EntryInputStream$vtype	_jc_java_util_jar_JarFile__24EntryInputStream$vtype;

// Constructors
extern void _jc_java_util_jar_JarFile__24EntryInputStream$method$_init$a2cee451c38f95fe(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, struct _jc_java_util_zip_ZipEntry$object *, struct _jc_java_io_InputStream$object *, struct _jc_java_util_jar_JarFile$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_jar_JarFile__24EntryInputStream$method$eof$36b390d2a773f09b(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_jar_JarFile__24EntryInputStream$method$mark$422af117ab27d9db(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_util_jar_JarFile__24EntryInputStream$method$markSupported$66435a81b7b2f2dc(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_jar_JarFile__24EntryInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_jar_JarFile__24EntryInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern jint _jc_java_util_jar_JarFile__24EntryInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_util_jar_JarFile__24EntryInputStream$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *) _JC_JCNI_ATTR;
extern jlong _jc_java_util_jar_JarFile__24EntryInputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, jlong) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$eof$36b390d2a773f09b;
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$mark$422af117ab27d9db;
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$markSupported$66435a81b7b2f2dc;
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_java_util_jar_JarFile__24EntryInputStream$method_info$skip$4e431136b5c4614a;

// Virtual methods structure
struct _jc_java_util_jar_JarFile__24EntryInputStream$vmethods {
	void	(*eof$36b390d2a773f09b)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *) _JC_JCNI_ATTR;
	void	(*mark$422af117ab27d9db)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, jint) _JC_JCNI_ATTR;
	jboolean	(*markSupported$66435a81b7b2f2dc)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *) _JC_JCNI_ATTR;
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_util_jar_JarFile__24EntryInputStream$object *, jlong) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_jar_JarFile__24EntryInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_java_util_jar_JarFile__24EntryInputStream$vmethods	java_util_jar_JarFile__24EntryInputStream;
};

// Vtype
struct _jc_java_util_jar_JarFile__24EntryInputStream$vtype {
	_jc_type			type;
	_jc_java_util_jar_JarFile__24EntryInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_jar_JarFile__24EntryInputStream$sub_refs {
	struct _jc_java_util_jar_JarFile$object	*jarfile;
	struct _jc_java_util_zip_ZipEntry$object	*entry;
	_jc_object_array	*hashes;
	_jc_object_array	*md;
};

// Reference instance fields (object)
struct _jc_java_util_jar_JarFile__24EntryInputStream$refs {
    _jc_java_util_jar_JarFile__24EntryInputStream$sub_refs	java_util_jar_JarFile__24EntryInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_jar_JarFile__24EntryInputStream$sub_nonrefs {
	jlong	length;
	jlong	pos;
	jboolean	checked;
};

// Non-reference instance fields (object)
struct _jc_java_util_jar_JarFile__24EntryInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_java_util_jar_JarFile__24EntryInputStream$sub_nonrefs	java_util_jar_JarFile__24EntryInputStream;
};

// Object instance structure
struct _jc_java_util_jar_JarFile__24EntryInputStream$object {
	_jc_java_util_jar_JarFile__24EntryInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_jar_JarFile__24EntryInputStream$vtype	*vtype;
	_jc_java_util_jar_JarFile__24EntryInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_jar_JarFile__24EntryInputStream$vtype _jc_java_util_jar_JarFile__24EntryInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_jar_JarFile__24EntryInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_jar_JarFile__24EntryInputStream$class_object;

#endif	/* _JC_java_util_jar_JarFile__24EntryInputStream_H_ */
